package wusthelper.web.api.v2.module.graduate;

import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import wusthelper.web.api.v2.TokenTool;
import wusthelper.web.api.v2.dto.response.CourseResponse;
import wusthelper.web.api.v2.dto.response.GraduateScoreResponse;
import wusthelper.web.api.v2.dto.response.GraduateStudentInfoResponse;
import wusthelper.web.api.v2.dto.response.StudentInfoResponse;
import wusthelper.web.response.Response;
import wusthelper.web.service.campus.graduate.GraduateCourseTableService;
import wusthelper.web.service.campus.graduate.GraduateScoreService;
import wusthelper.web.service.campus.graduate.GraduateStudentInfoService;
import wusthelper.web.service.campus.graduate.GraduateTrainingPlanService;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/v2/yjs")
public class GraduateController {

    private final GraduateStudentInfoService studentInfoService;
    private final GraduateCourseTableService courseTableService;
    private final GraduateScoreService scoreService;
    private final GraduateTrainingPlanService trainingPlanService;

    public GraduateController(GraduateStudentInfoService studentInfoService,
                              GraduateCourseTableService courseTableService,
                              GraduateScoreService scoreService,
                              GraduateTrainingPlanService trainingPlanService) {

        this.studentInfoService = studentInfoService;
        this.courseTableService = courseTableService;
        this.scoreService = scoreService;
        this.trainingPlanService = trainingPlanService;
    }

    @RequestMapping("/get-student-info")
    public Response<GraduateStudentInfoResponse> getStudentInfo(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var studentInfo = studentInfoService.getStudentInfo(user);
        var response = GraduateStudentInfoResponse.from(studentInfo);

        return Response.success(response);
    }

    @RequestMapping("/get-course")
    public Response<List<CourseResponse>> getCourses(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var courses = courseTableService.getCourseTable(user);
        var resultList = new ArrayList<CourseResponse>(courses.size());
        for (var course : courses) {
            resultList.add(CourseResponse.from(course));
        }

        return Response.success(resultList);
    }

    @RequestMapping("/get-grade")
    public Response<List<GraduateScoreResponse>> getScore(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var scores = scoreService.getScore(user);
        var resultList = new ArrayList<GraduateScoreResponse>(scores.size());
        for (var score : scores) {
            resultList.add(GraduateScoreResponse.from(score));
        }

        return Response.success(resultList);
    }

    @RequestMapping("/get-scheme")
    public Response<String> getTrainingPlan(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var page = trainingPlanService.getTrainingPlan(user);

        return Response.success(page);
    }
}
