package wusthelper.web.api.v2.module.physics;

import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import wusthelper.web.api.v2.TokenTool;
import wusthelper.web.api.v2.dto.response.CourseResponse;
import wusthelper.web.api.v2.dto.response.PhysicsCourseResponse;
import wusthelper.web.api.v2.dto.response.ScoreResponse;
import wusthelper.web.response.Response;
import wusthelper.web.service.campus.physics.PhysicsCourseTableService;
import wusthelper.web.service.campus.physics.PhysicsScoreService;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/v2/wlsy")
public class PhysicsController {

    private final PhysicsCourseTableService courseTableService;
    private final PhysicsScoreService scoreService;

    public PhysicsController(PhysicsCourseTableService courseTableService,
                             PhysicsScoreService scoreService) {

        this.courseTableService = courseTableService;
        this.scoreService = scoreService;
    }

    @RequestMapping("/get-course")
    public Response<List<PhysicsCourseResponse>> getCourses(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var courses = courseTableService.getCourseTable(user);
        var resultList = new ArrayList<PhysicsCourseResponse>(courses.size());
        for (var course : courses) {
            resultList.add(PhysicsCourseResponse.from(course));
        }

        return Response.success(resultList);
    }

    @RequestMapping("/get-grade")
    public Response<List<ScoreResponse>> getScore(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var scores = scoreService.getScore(user);
        var resultList = new ArrayList<ScoreResponse>(scores.size());
        for (var score : scores) {
            resultList.add(ScoreResponse.from(score));
        }

        return Response.success(resultList);
    }
}
